| sumDlogNorm | R Documentation |
This is an internal function that is only exposed on the public API for unit testing purposes.
sumDlogNorm(x, meanlog, sdlog)
x |
Vector of i.i.d. lognormal random varibles |
meanlog |
mean of the distribution on the log scale |
sdlog |
standard deviation on the log scale |
The sum of the log-likelihoods (log of the product of the likelihoods) for independent, identically-distributed, lognormal random variables. Note: this Rcpp function is thread-safe, unlike the equivalent alternatives.
log-likelihood of x
sum(dlnorm(x, meanlog, sdlog, log=TRUE))
x <- rlnorm(100)
sumDlogNorm(x,0,1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.